@@ -15,7 +15,7 @@ class AllowedPattern(CloudFormationLintRule):
     id = 'E3031'
     shortdesc = 'Check if property values adhere to a specific pattern'
     description = 'Check if properties have a valid value in case of a pattern (Regular Expression)'
-    source_url = 'https://github.com/awslabs/cfn-python-lint/blob/master/docs/cfn-resource-specification.md#allowedpattern'
+    source_url = 'https://github.com/awslabs/cfn-python-lint/blob/main/docs/cfn-resource-specification.md#allowedpattern'
     tags = ['resources', 'property', 'allowed pattern', 'regex']
 
     def initialize(self, cfn):
