@@ -13,7 +13,7 @@ class Properties(CloudFormationLintRule):
     id = 'E3002'
     shortdesc = 'Resource properties are valid'
     description = 'Making sure that resources properties are properly configured'
-    source_url = 'https://github.com/aws-cloudformation/cfn-python-lint/blob/master/docs/cfn-resource-specification.md#properties'
+    source_url = 'https://github.com/aws-cloudformation/cfn-python-lint/blob/main/docs/cfn-resource-specification.md#properties'
     tags = ['resources']
 
     def __init__(self):
